@@ -1,6 +1,9 @@
 // Take a look at the license at the top of the repository in the LICENSE file.
 
 #![cfg_attr(feature = "dox", feature(doc_cfg))]
+#![allow(clippy::missing_safety_doc)]
+#![allow(clippy::non_send_fields_in_send_ty)]
+#![doc = include_str!("../README.md")]
 
 pub use ffi;
 pub use glib;
@@ -24,15 +27,17 @@ macro_rules! skip_assert_initialized {
 #[allow(clippy::too_many_arguments)]
 #[allow(clippy::match_same_arms)]
 #[allow(clippy::use_self)]
+#[allow(unused_imports)]
 mod auto;
+pub use crate::auto::functions::*;
 pub use crate::auto::*;
 
 mod caps_features;
-pub use crate::caps_features::{CAPS_FEATURES_MEMORY_GL_MEMORY, CAPS_FEATURE_MEMORY_GL_MEMORY};
+pub use crate::caps_features::CAPS_FEATURES_MEMORY_GL_MEMORY;
 mod context;
+pub mod functions;
+pub use crate::functions::*;
 mod gl_context;
-mod gl_display;
-pub use crate::gl_display::GL_DISPLAY_CONTEXT_TYPE;
 mod gl_sync_meta;
 mod gl_video_frame;
 pub use crate::gl_sync_meta::*;
